@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals
 
-from .exists import Exists
+from .aggregations import Aggregations  # noqa
+from .exists import Exists  # noqa
 from .geo import GeoDistance  # noqa
 from .match_all import MatchAll  # noqa
 from .missing import Missing  # noqa
@@ -14,6 +15,7 @@ from .terms import Terms  # noqa
 from .type import Type  # noqa
 
 __all__ = (
+    'Aggregations',
     'Exists',
     'GeoDistance',
     'MatchAll',
