@@ -1,12 +1,11 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals, absolute_import
 
-import json
 from copy import deepcopy
 
 from elasticsearch import Elasticsearch
 from six import string_types
-from . import Filter, Bool, QueryBuilder
+from . import QueryBuilder
 
 
 class QuerySet(object):
@@ -19,9 +18,11 @@ class QuerySet(object):
         else:
             self._q = QueryBuilder(query_string=query)
         self._wrappers = []
+        self._post_query_actions = []
         self._count = None
         self._conn = None
         self._finalized_query = None
+        self._aggregations = None
         # Caching
         self._cache = None
         self._retrieved = 0
@@ -62,9 +63,20 @@ class QuerySet(object):
         self._wrappers.append(wrapper)
         return self
 
+    def post_query_actions(self, action):
+        self._post_query_actions.append(action)
+        return self
+
     def count(self):
         return self._count
 
+    def aggregations(self):
+        return self._aggregations
+
+    def aggregate(self, aggregation):
+        self._q.aggregate(aggregation)
+        return self
+
     def __next__(self):
         return self.next()  # pragma: no cover
 
@@ -111,9 +123,14 @@ class QuerySet(object):
         """
         start = val.start
         end = val.stop
-        results = self._search(start, end)
+        raw_results = self._search(start, end)
+        for action in self._post_query_actions:
+            action(self, raw_results, start, end)
+        results = raw_results["hits"]["hits"]
         for wrapper in self._wrappers:
             results = wrapper(results)
+        if raw_results.get('aggregations'):
+            self._aggregations = raw_results.get('aggregations')
         return results
 
     def _search(self, start, end):
@@ -121,7 +138,7 @@ class QuerySet(object):
         pagination_kwargs = self._get_pagination_kwargs(start, end)
         raw_results = conn.search(index=self._index, body=self._query, **pagination_kwargs)
         self._count = self._get_result_count(raw_results)
-        return raw_results["hits"]["hits"]
+        return raw_results
 
     def _get_result_count(self, results):
         return int(results["hits"]["total"])
